from wagtail.blocks import *
# from wagtail.images.blocks import ImageBlock
from wagtail.images.blocks import ImageChooserBlock

from wagtail.admin.panels import FieldPanel, MultiFieldPanel, FieldRowPanel
from wagtailmodelchooser.blocks import ModelChooserBlock
# from web.models import ExportCountry
from wagtail.documents.blocks import DocumentChooserBlock
from wagtail_color_panel.blocks import NativeColorBlock

from .common import *

class TileViewBlock(StreamBlock):
    tile = StructBlock([
        ("tileBgColor", NativeColorBlock(default="#000000", label="Tile BG Color")),
        ("image", ImageChooserBlock(required=False)),
        ("label", CharBlock(required=False)),
        ("title", CharBlock(required=False)),
        ("page", PageChooserBlock(required=False)),
    ])

class SocialBlock(StreamBlock):
    social_link = ModelChooserBlock('core.Social')

class ComInfoBlock(StreamBlock):
    info = ModelChooserBlock('core.CompanyInfo')
    # class Meta:
    #     icon = 'globe'

class CategoryBlock(StructBlock):
    category = PageChooserBlock('ecom.CategoryPage')
    label = CharBlock(required=False)

class BaseColumnBlock(StreamBlock):
    heading = HeadingBlock(required=False)
    hr_line = HRLine(required=False)
    line_break = LineBreak(required=False)
    paragraph = ParagraphBlock(required=False)
    cta = CTA(required=False)
    image = ImageChooserBlock(required=False)
    quote = QuoteBlock(required=False)

    # category=PageChooserBlock('ecom.CategoryPage')
    social = SocialBlock(required=False)
    company = ComInfoBlock(required=False)
    policy = ModelChooserBlock('core.ComPolicy')
    category = CategoryBlock(required=False)
    product = PageChooserBlock('ecom.ProductPage')
    page = PageChooserBlock()
    tile = PageChooserBlock()
    tile_View = TileViewBlock(required=False)
    show_enq_form = BooleanBlock(required=False, label="Show Enquiry Form")


class BaseRowBlock(StructBlock):
    bgColor = NativeColorBlock(default="#000000", label="BG Color")
    fgColor = NativeColorBlock(default="#FFFFFF", label="FG Color")
    title = CharBlock(required=False)

    content = StreamBlock(
        [
            ("column", BaseColumnBlock(required=False))
        ]
    )


class ColumnBlock(BaseColumnBlock):

    sub_row = BaseRowBlock(required=False)


# Main Blocks


class RowBlock(StructBlock):
    bgColor = NativeColorBlock(default="#FFFFFF", label="BG Color")
    fgColor = NativeColorBlock(default="#000000", label="FG Color")
    title = CharBlock(required=False)

    content = StreamBlock(
        [
            ("column", ColumnBlock(required=False))
        ], required=False
    )


class SectionBlock(StructBlock):
    bgColor = NativeColorBlock(default="#FFFFFF", label="BG Color")
    fgColor = NativeColorBlock(default="#000000", label="FG Color")
    title = CharBlock(required=False)
    # type = ModelChooserBlock('blogs.PageBlockType', required=False)

    content = StreamBlock(
        [
            ("heading", HeadingBlock(required=False)),
            ("hr_line", HRLine(required=False)),
            ("line_break", LineBreak(required=False)),
            ('cta', CTA(required=False)),
            ("paragraph", ParagraphBlock(required=False)),
            ("image", ImageChooserBlock(required=False)),
            ("categories",StreamBlock([
                
            ("category", CategoryBlock(required=False)),
            ],required=False)),
            ("news",StreamBlock([
            ("page", PageChooserBlock('blogs.NewsPage',required=False)),
            ],required=False)),
            # ("category", PageChooserBlock('ecom.CategoryPage')),
            ("products",StreamBlock([
                ("product", PageChooserBlock('ecom.ProductPage')),
                ],required=False)),
            # ("tile_View", TileViewBlock(required=False)),
            ("tile_View", StructBlock([
                ('tile_Type', ChoiceBlock(choices=[
                    ('Round', 'Round'), ('Normal', 'Normal')], default="Round")),
                ("tile_View", TileViewBlock(required=False)),
            ], required=False)),
            ("quote", QuoteBlock(required=False)),
        ], required=False
    )
      # class Meta:
      #     icon = 'user'


class xStoryTitle(StructBlock):
    title = CharBlock(required=False)
    title_font_size = ChoiceBlock(
        choices=FONT_SIZE_LIST, required=False, label="Title Font Size")
    title_font_type = ChoiceBlock(
        choices=FONT_FAMILY_LIST, required=False, label="Title Font Family")
    title_fgColor = NativeColorBlock(required=False, label="Title FG Color")
    title_bgColor = NativeColorBlock(required=False, label="Title BG Color")


class xStoryCTA(StructBlock):
    text = CharBlock(required=False)
    bgColor = NativeColorBlock(required=False, label="CTA BG Color")
    fgColor = NativeColorBlock(required=False, label="CTA FG Color")
    url = CharBlock(required=False, label="External URL")
    page = PageChooserBlock(required=False, label="Internal URL")


class xStoryTheme(StructBlock):
    position = ChoiceBlock(choices=STORY_THEME_POSITION,
                           required=False, label="Position")
    font_type = ChoiceBlock(choices=FONT_FAMILY_LIST,
                            required=False, label="Font Family")
    font_size = ChoiceBlock(choices=FONT_SIZE_LIST,
                               required=False, label="Font Size")
    bgColor = NativeColorBlock(
            default="#FFFFFF", label="Slide BG Color")
    fgColor = NativeColorBlock(
               default="#000000", label="Slide FG Color")

    content = StreamBlock([
        ("title", xStoryTitle()),
        ("desc", RichTextBlock()),
        ("cta", xStoryCTA(label="CTA")),
    ])

class WebStoryBlock(StructBlock):
    timer = IntegerBlock(default=5, help_text="Slide time in second")
    content = StreamBlock(
        [
            ("image", ImageChooserBlock(required=True, max_num=1)),
            ("theme", xStoryTheme())
            ]
    )

        # Footer Blocks

class FooterBaseColumnBlock(StructBlock):
    width = CharBlock(default="50%", required=False)
    content = StreamBlock([
        ("heading", HeadingBlock(required=False)),
        ("paragraph", ParagraphBlock(required=False)),
        ("social", SocialBlock(required=False)),
        ("company", ComInfoBlock(required=False)),
        ("policy", ModelChooserBlock('core.ComPolicy')),
        ("image", ImageChooserBlock(required=False)),
        ("category", CategoryBlock(required=False)),
        ("link", PageChooserBlock(required=False)),
    ])

class FooterBaseRowBlock(StreamBlock):
    column = FooterBaseColumnBlock(required=False)

class FooterColumnBlock(StructBlock):
    width = CharBlock(default="50%", required=False)
    show_in_mobile = BooleanBlock(default=True, required=False)
    content = StreamBlock([
        ("heading", HeadingBlock(required=False)),
        ("hr_line", StructBlock([
            ('color', NativeColorBlock(
                required=False, default="", label="BG Color")),
            ('double_color', StructBlock([
                ('oneColor', NativeColorBlock(
                    required=False, default="", label="One Color")),
                ('twoColor', NativeColorBlock(
                    required=False, default="", label="Two Color")),
            ])),
            ('gradient', CharBlock(required=False)),
            ('width', CharBlock(default='100', label="Width (px)")),
            ('thickness', CharBlock(default="4", label="Thickness (px)")),
            ('margin', StructBlock([
                ('top', DecimalBlock(
                    default=0, label="Top (px)")),
                ('bottom', DecimalBlock(
                    default=8, label="Bottom (px)")),
            ])),
        ], required=False, label="HR Line",)),
        ("line_break", CharBlock(required=False,
            label="Line Break", readOnly=True)),
        ("paragraph", ParagraphBlock(required=False)),
        ("social", SocialBlock(required=False)),
        ("company", ComInfoBlock(required=False)),
        ("policy", ModelChooserBlock('core.ComPolicy')),
        ("sub_row", FooterBaseRowBlock(required=False)),
        ("image", ImageChooserBlock(required=False)),
        ("category", CategoryBlock(required=False)),
        ("link", PageChooserBlock(required=False)),
    ], required=False)

class FooterRowBlock(StreamBlock):
    column = FooterColumnBlock(required=False)

    # Burger Menu

class BurgerSectionBlock(StreamBlock):
    heading = HeadingBlock(required=False)
    image = ImageChooserBlock(required=False)
    page = PageChooserBlock()
    hr_line = StructBlock([
        ('color', NativeColorBlock(
            required=False, default="", label="BG Color")),
        ('double_color', StructBlock([
            ('oneColor', NativeColorBlock(
                required=False, default="", label="One Color")),
            ('twoColor', NativeColorBlock(
                required=False, default="", label="Two Color")),
        ])),
        ('gradient', CharBlock(required=False)),
        ('width', CharBlock(default='100', label="Width (px)")),
        ('thickness', CharBlock(default="4", label="Thickness (px)")),
        ('margin', StructBlock([
            ('top', DecimalBlock(
                default=0, label="Top (px)")),
            ('bottom', DecimalBlock(
                default=8, label="Bottom (px)")),
        ])),
    ], required=False, label="HR Line",)
    line_break = CharBlock(required=False,
                            label = "Line Break", readOnly = True)
    social = SocialBlock(required=False)
    company = ComInfoBlock(required=False)
    policy = ModelChooserBlock('core.ComPolicy')
